Re: Maintainer for nvidia-crap in lvn wanted (Re: Pull off AIGLX repoistory?)

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Op zo, 30-07-2006 te 12:56 +0200, schreef Erik van Pienbroek:
> Looks like the module generator wasn't able to retrieve the kernel
> version... (yes, kernel-devel is installed on my computer and the
> directory mentioned does exist)

After further investigation I've found the cause of this problem.
After applying some changes I was able to get past the detection
part, but the compile itself still fails :

ATI module generator V 2.0
==========================
initializing...
cleaning...
patching 'highmem.h'...
assuming new VMA API since we do have kernel 2.6.x...
 Assuming default VMAP API
doing Makefile based build for kernel 2.6.x and higher
make -C /lib/modules/2.6.17-1.2462.fc6/build
SUBDIRS=/lib/modules/fglrx/build_mod/2.6.x modules
make[1]: Map '/usr/src/kernels/2.6.17-1.2462.fc6-x86_64' wordt
binnengegaan
  CC [M]  /lib/modules/fglrx/build_mod/2.6.x/firegl_public.o
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c: In functie
‘firegl_stub_open’:
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:560: let op:
assignment discards qualifiers from pointer target type
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c: In functie
‘firegl_put_user_ptr’:
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:1320: let op: cast
van pointer naar integer met andere grootte
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:1320: let op: cast
van pointer naar integer met andere grootte
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:1320: let op: cast
van pointer naar integer met andere grootte
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:1320: let op: cast
van pointer naar integer met andere grootte
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c: In functie
‘__ke_unregister_ioctl32_conversion’:
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:2500: let op:
‘return’ with a value, in function returning void
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c: In functie
‘__ke_vm_map’:
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:3160: fout: ‘VM_SHM’
undeclared (first use in this function)
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:3160: fout: (Each
undeclared identifier is reported only once
/lib/modules/fglrx/build_mod/2.6.x/firegl_public.c:3160: fout: for each
function it appears in.)
make[2]: *** [/lib/modules/fglrx/build_mod/2.6.x/firegl_public.o] Fout 1
make[1]: *** [_module_/lib/modules/fglrx/build_mod/2.6.x] Fout 2
make[1]: Map '/usr/src/kernels/2.6.17-1.2462.fc6-x86_64' wordt verlaten
make: *** [kmod_build] Fout 2
build failed with return value 2

I wasn't able to find an occurence of the symbol VM_SHM in the
kernel-devel package, so I kinda landed at an dead end..

Anyway, if someone would like to further investigate this issue, I've
attached a patch to this mail containing the changes I've needed to
apply to get this far. Hopefully someone else can further fix this
issue.

Regards,

Erik van Pienbroek

--- /lib/modules/fglrx/build_mod/2.6.x/firegl_public.c.orig	2006-07-30 13:14:23.000000000 +0200
+++ /lib/modules/fglrx/build_mod/2.6.x/firegl_public.c	2006-07-30 13:14:34.000000000 +0200
@@ -23,6 +23,7 @@
 
 // ============================================================
 #include <linux/version.h>
+#include <linux/utsrelease.h>
 #ifdef MODVERSIONS
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,71)
 #include <linux/modversions.h>
--- /lib/modules/fglrx/build_mod/make.sh.orig	2006-07-30 13:09:52.000000000 +0200
+++ /lib/modules/fglrx/build_mod/make.sh	2006-07-30 13:11:28.000000000 +0200
@@ -222,8 +222,8 @@
   then
     kernel_release=`cat $src_file | grep UTS_RELEASE | cut -d'"' -f2`
   else
-    # UTS-define is in external version-*.h files, i.e. linux-2.2.14-5.0-RedHat does this flaw
-    kernel_release=`cat $linuxincludes/linux/version-*.h | grep UTS_RELEASE | grep \"$OsRelease\" | cut -d'"' -f2`
+    # UTS-define is in external utsrelease.h file, i.e. linux-2.6.17-1.2462.fc6 does this flaw
+    kernel_release=`cat $linuxincludes/linux/utsrelease.h | grep UTS_RELEASE | grep \"$OsRelease\" | cut -d'"' -f2`
   fi
 fi
 
-- 
fedora-devel-list mailing list
fedora-devel-list@xxxxxxxxxx
https://www.redhat.com/mailman/listinfo/fedora-devel-list

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Index of Archives]     [Fedora Announce]     [Fedora Kernel]     [Fedora Testing]     [Fedora Formulas]     [Fedora PHP Devel]     [Kernel Development]     [Fedora Legacy]     [Fedora Maintainers]     [Fedora Desktop]     [PAM]     [Red Hat Development]     [Gimp]     [Yosemite News]
  Powered by Linux